@@ -39,8 +39,8 @@ def fill_empty_fields(keys, data):
 
 
 class DBManager(object):
-    def __init__(self, connstr):
-        self.engine = create_engine(connstr, echo=False, encoding='utf8')
+    def __init__(self, connstr, **kwargs):
+        self.engine = create_engine(connstr, echo=False, encoding='utf8', **kwargs)
 
     def insert(self, table, data, exist_action=ea_ignore):
         """
